VERSION = "0.1.8"
HEADER = r"""'||'''|,  '||'''|, |''||''|                                  
 ||   ||   ||   ||    ||                                     
 ||;;;;    ||...|'    ||    '||),,(|,   '''|.  .|''|, .|''|, 
 ||   ||   || \\      ||     || || ||  .|''||  ||  || ||..|| 
.||...|'  .||  \\. |..||..| .||    ||. `|..||. `|..|| `|...  
                                                   || v{}     
                                                `..|'
""".format(
    VERSION
)
